@@ -20,9 +20,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 02110-1301  USA
 """
-import string
 import yaml
 
+from string import Template
+
+
 class YamlConfig(dict):
     """
     YAML configuration file reader with basic variable interpolation.
@@ -45,23 +47,26 @@ class YamlConfig(dict):
         for entry in indict:
             self[entry] = indict[entry]
 
-    def _interpolate(self, infile, defaults):
+    def _interpolate(self):
         """
         Interpolate variables.
         """
-        with open(infile, 'r') as config:
-            template = string.Template(config.read())
-            interpolated_config = template.safe_substitute(defaults)
+        with open(self.infile, 'r') as config:
+            template = Template(config.read())
+            interpolated_config = template.safe_substitute(self.defaults)
         return interpolated_config
 
-    def _deserialize(self, infile):
+    def _deserialize(self):
         """
         Deserialize YAML string.
         """
-        config = yaml.load(infile)
+        config = yaml.load(self.infile)
         return config
 
     def get_config(self):
-        self.infile = self._interpolate(self.infile, self.defaults)
-        config = self._deserialize(self.infile)
+        """
+        Parse and return the configuration object.
+        """
+        self.infile = self._interpolate()
+        config = self._deserialize()
         return config
